@@ -38,6 +38,10 @@ class RenderSlideDirective(BaseDirective):
 		if len(self._content_containers) == 0:
 			self._content_containers["default"] = self._dom
 
+	@property
+	def xmlnode(self):
+		return self._dom
+
 	@property
 	def slide_type(self):
 		return self._dom.getAttribute("type")
