@@ -107,7 +107,7 @@ class XMLTools():
 	def findall(cls, root_node, name, namespace_uri = "*"):
 		result = [ ]
 		for node in root_node.childNodes:
-			if (node.nodeType == node.ELEMENT_NODE) and (node.tagName == name) and ((namespace_uri == "*") or (node.namespaceURI == namespace_uri)):
+			if (node.nodeType == node.ELEMENT_NODE) and (node.tagName == name) and (namespace_uri in ("*", node.namespaceURI)):
 				result.append(node)
 		return result
 
@@ -207,7 +207,22 @@ class ImageTools():
 		return image_info
 
 class HashTools():
+	@classmethod
+	def _update_file(cls, hashfnc, f):
+		while True:
+			chunk = f.read(1024 * 1024)
+			if len(chunk) == 0:
+				break
+			hashfnc.update(chunk)
+
+	@classmethod
+	def hash_files(cls, filenames):
+		hashfnc = hashlib.md5()
+		for filename in filenames:
+			with open(filename, "rb") as f:
+				cls._update_file(hashfnc, f)
+		return hashfnc.hexdigest()
+
 	@classmethod
 	def hash_file(cls, filename):
-		with open(filename, "rb") as f:
-			return hashlib.md5(f.read()).hexdigest()
+		return cls.hash_files([ filename ])
