@@ -27,6 +27,8 @@ from .ActionRender import ActionRender
 from .ActionServe import ActionServe
 from .ActionAcroSort import ActionAcroSort
 from .ActionPurge import ActionPurge
+from .ActionHashPresentation import ActionHashPresentation
+from .ActionDumpMetadata import ActionDumpMetadata
 from .Enums import PresentationMode, PresentationFeature
 
 def _geometry(text):
@@ -36,7 +38,7 @@ def _geometry(text):
 	return (int(text[0]), int(text[1]))
 
 def main():
-	mc = MultiCommand(trailing_text = "version: pyradium v%s" % (pyradium.VERSION))
+	mc = MultiCommand(description = "HTML presentation/slide show generator", trailing_text = "version: pyradium v%s" % (pyradium.VERSION))
 
 	def genparser(parser):
 		parser.add_argument("--image-max-dimension", metavar = "pixels", type = int, default = 1920, help = "When rendering imaages, specifies the maximum dimension they're downsized to. The lower this value, the smaller the output files and the lower the quality. Defaults to %(default)d pixels.")
@@ -47,6 +49,7 @@ def main():
 		parser.add_argument("-r", "--remove-pauses", action = "store_true", help = "Ignore all pause directives and just render the final slides.")
 		parser.add_argument("--collapse-animation", action = "store_true", help = "Do not render animations as multiple slides, just show one complete slide.")
 		parser.add_argument("-i", "--index-filename", metavar = "filename", default = "index.html", help = "Gives the name of the presentation index file. Defaults to %(default)s. Useful if you want to render multiple presentations in one subdirectory.")
+		parser.add_argument("-j", "--inject-metadata", metavar = "filename", help = "Gives the option to inject metadata into the presentation. Must point to a JSON filename and will override the respective metadata fields of the presentation. Useful for changing things like the presentation date on the command line.")
 		parser.add_argument("-m", "--presentation-mode", metavar = "{%s}" % (",".join(enumitem.value for enumitem in PresentationMode)), type = PresentationMode, default = "interactive", help = "Generate this type of presentation. Can be one of %(choices)s, defaults to %(default)s.")
 		parser.add_argument("-F", "--presentation-feature", metavar = "{%s}" % (",".join(enumitem.value for enumitem in PresentationFeature)), type = PresentationFeature, default = [ ], action = "append", help = "Enable a specific presentation feature. Can be one of %(choices)s and can be given multiple times.")
 		parser.add_argument("-l", "--re-render-loop", action = "store_true", help = "Stay in a continuous loop, re-rendering the presentation if anything changes.")
@@ -72,6 +75,21 @@ def main():
 	def genparser(parser):
 		parser.add_argument("-v", "--verbose", action = "count", default = 0, help = "Increases verbosity. Can be specified multiple times to increase.")
 	mc.register("purge", "Purge the document cache", genparser, action = ActionPurge)
+
+	def genparser(parser):
+		parser.add_argument("-I", "--include-dir", metavar = "path", action = "append", default = [ ], help = "Specifies an additional include directory in which, for example, images are located which are referenced from the presentation. Can be issued multiple times.")
+		parser.add_argument("-v", "--verbose", action = "count", default = 0, help = "Increases verbosity. Can be specified multiple times to increase.")
+		parser.add_argument("infile", help = "Input XML file of the slide show.")
+	mc.register("hash", "Create a hash of a presentation and all dependencies to detect modifications", genparser, action = ActionHashPresentation)
+
+	def genparser(parser):
+		parser.add_argument("-p", "--pretty-print", action = "store_true", help = "Pretty print the output JSON data.")
+		parser.add_argument("-I", "--include-dir", metavar = "path", action = "append", default = [ ], help = "Specifies an additional include directory in which, for example, images are located which are referenced from the presentation. Can be issued multiple times.")
+		parser.add_argument("-j", "--inject-metadata", metavar = "filename", help = "Gives the option to inject metadata into the presentation. Must point to a JSON filename and will override the respective metadata fields of the presentation. Useful for changing things like the presentation date on the command line.")
+		parser.add_argument("-v", "--verbose", action = "count", default = 0, help = "Increases verbosity. Can be specified multiple times to increase.")
+		parser.add_argument("infile", help = "Input XML file of the slide show.")
+	mc.register("dumpmeta", "Dump the metadata dictionary in JSON format", genparser, action = ActionDumpMetadata)
+
 	return mc.run(sys.argv[1:])
 
 if __name__ == "__main__":
